@@ -27,7 +27,7 @@ import gitlab.v4.objects
 from gitlab import cli
 
 
-class GitlabCLI(object):
+class GitlabCLI:
     def __init__(
         self, gl: gitlab.Gitlab, what: str, action: str, args: Dict[str, str]
     ) -> None:
@@ -94,6 +94,7 @@ class GitlabCLI(object):
         return self.do_custom()
 
     def do_custom(self) -> Any:
+        class_instance: Union[gitlab.base.RESTManager, gitlab.base.RESTObject]
         in_obj = cli.custom_actions[self.cls_name][self.action][2]
 
         # Get the object (lazy), then act
@@ -106,11 +107,12 @@ class GitlabCLI(object):
                 if TYPE_CHECKING:
                     assert isinstance(self.cls._id_attr, str)
                 data[self.cls._id_attr] = self.args.pop(self.cls._id_attr)
-            obj = self.cls(self.mgr, data)
-            method_name = self.action.replace("-", "_")
-            return getattr(obj, method_name)(**self.args)
+            class_instance = self.cls(self.mgr, data)
         else:
-            return getattr(self.mgr, self.action)(**self.args)
+            class_instance = self.mgr
+
+        method_name = self.action.replace("-", "_")
+        return getattr(class_instance, method_name)(**self.args)
 
     def do_project_export_download(self) -> None:
         try:
@@ -198,11 +200,15 @@ def _populate_sub_parser_by_class(
     mgr_cls_name = f"{cls.__name__}Manager"
     mgr_cls = getattr(gitlab.v4.objects, mgr_cls_name)
 
+    action_parsers: Dict[str, argparse.ArgumentParser] = {}
     for action_name in ["list", "get", "create", "update", "delete"]:
         if not hasattr(mgr_cls, action_name):
             continue
 
-        sub_parser_action = sub_parser.add_parser(action_name)
+        sub_parser_action = sub_parser.add_parser(
+            action_name, conflict_handler="resolve"
+        )
+        action_parsers[action_name] = sub_parser_action
         sub_parser_action.add_argument("--sudo", required=False)
         if mgr_cls._from_parent_attrs:
             for x in mgr_cls._from_parent_attrs:
@@ -216,8 +222,8 @@ def _populate_sub_parser_by_class(
                     f"--{x.replace('_', '-')}", required=False
                 )
 
-            sub_parser_action.add_argument("--page", required=False)
-            sub_parser_action.add_argument("--per-page", required=False)
+            sub_parser_action.add_argument("--page", required=False, type=int)
+            sub_parser_action.add_argument("--per-page", required=False, type=int)
             sub_parser_action.add_argument("--all", required=False, action="store_true")
 
         if action_name == "delete":
@@ -266,7 +272,11 @@ def _populate_sub_parser_by_class(
     if cls.__name__ in cli.custom_actions:
         name = cls.__name__
         for action_name in cli.custom_actions[name]:
-            sub_parser_action = sub_parser.add_parser(action_name)
+            # NOTE(jlvillal): If we put a function for the `default` value of
+            # the `get` it will always get called, which will break things.
+            sub_parser_action = action_parsers.get(action_name)
+            if sub_parser_action is None:
+                sub_parser_action = sub_parser.add_parser(action_name)
             # Get the attributes for URL/path construction
             if mgr_cls._from_parent_attrs:
                 for x in mgr_cls._from_parent_attrs:
@@ -296,7 +306,11 @@ def _populate_sub_parser_by_class(
     if mgr_cls.__name__ in cli.custom_actions:
         name = mgr_cls.__name__
         for action_name in cli.custom_actions[name]:
-            sub_parser_action = sub_parser.add_parser(action_name)
+            # NOTE(jlvillal): If we put a function for the `default` value of
+            # the `get` it will always get called, which will break things.
+            sub_parser_action = action_parsers.get(action_name)
+            if sub_parser_action is None:
+                sub_parser_action = sub_parser.add_parser(action_name)
             if mgr_cls._from_parent_attrs:
                 for x in mgr_cls._from_parent_attrs:
                     sub_parser_action.add_argument(
@@ -324,16 +338,15 @@ def extend_parser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
     subparsers.required = True
 
     # populate argparse for all Gitlab Object
-    classes = []
+    classes = set()
     for cls in gitlab.v4.objects.__dict__.values():
         if not isinstance(cls, type):
             continue
         if issubclass(cls, gitlab.base.RESTManager):
             if cls._obj_cls is not None:
-                classes.append(cls._obj_cls)
-    classes.sort(key=operator.attrgetter("__name__"))
+                classes.add(cls._obj_cls)
 
-    for cls in classes:
+    for cls in sorted(classes, key=operator.attrgetter("__name__")):
         arg_name = cli.cls_to_what(cls)
         object_group = subparsers.add_parser(arg_name)
 
@@ -357,7 +370,7 @@ def get_dict(
     return obj.attributes
 
 
-class JSONPrinter(object):
+class JSONPrinter:
     def display(self, d: Union[str, Dict[str, Any]], **kwargs: Any) -> None:
         import json  # noqa
 
@@ -374,7 +387,7 @@ class JSONPrinter(object):
         print(json.dumps([get_dict(obj, fields) for obj in data]))
 
 
-class YAMLPrinter(object):
+class YAMLPrinter:
     def display(self, d: Union[str, Dict[str, Any]], **kwargs: Any) -> None:
         try:
             import yaml  # noqa
@@ -409,7 +422,7 @@ class YAMLPrinter(object):
             )
 
 
-class LegacyPrinter(object):
+class LegacyPrinter:
     def display(self, d: Union[str, Dict[str, Any]], **kwargs: Any) -> None:
         verbose = kwargs.get("verbose", False)
         padding = kwargs.get("padding", 0)
@@ -447,12 +460,12 @@ class LegacyPrinter(object):
             if obj._id_attr:
                 id = getattr(obj, obj._id_attr)
                 print(f"{obj._id_attr.replace('_', '-')}: {id}")
-            if obj._short_print_attr:
-                value = getattr(obj, obj._short_print_attr) or "None"
+            if obj._repr_attr:
+                value = getattr(obj, obj._repr_attr, "None")
                 value = value.replace("\r", "").replace("\n", " ")
                 # If the attribute is a note (ProjectCommitComment) then we do
                 # some modifications to fit everything on one line
-                line = f"{obj._short_print_attr}: {value}"
+                line = f"{obj._repr_attr}: {value}"
                 # ellipsize long lines (comments)
                 if len(line) > 79:
                     line = f"{line[:76]}..."
