@@ -21,7 +21,7 @@ __all__ = [
 
 
 class Snippet(UserAgentDetailMixin, SaveMixin, ObjectDeleteMixin, RESTObject):
-    _short_print_attr = "title"
+    _repr_attr = "title"
 
     @cli.register_custom_action("Snippet")
     @exc.on_http_error(exc.GitlabGetError)
@@ -50,7 +50,7 @@ class Snippet(UserAgentDetailMixin, SaveMixin, ObjectDeleteMixin, RESTObject):
         Returns:
             The snippet content
         """
-        path = f"/snippets/{self.get_id()}/raw"
+        path = f"/snippets/{self.encoded_id}/raw"
         result = self.manager.gitlab.http_get(
             path, streamed=streamed, raw=True, **kwargs
         )
@@ -91,7 +91,7 @@ class SnippetManager(CRUDMixin, RESTManager):
 
 class ProjectSnippet(UserAgentDetailMixin, SaveMixin, ObjectDeleteMixin, RESTObject):
     _url = "/projects/{project_id}/snippets"
-    _short_print_attr = "title"
+    _repr_attr = "title"
 
     awardemojis: ProjectSnippetAwardEmojiManager
     discussions: ProjectSnippetDiscussionManager
@@ -124,7 +124,7 @@ class ProjectSnippet(UserAgentDetailMixin, SaveMixin, ObjectDeleteMixin, RESTObj
         Returns:
             The snippet content
         """
-        path = f"{self.manager.path}/{self.get_id()}/raw"
+        path = f"{self.manager.path}/{self.encoded_id}/raw"
         result = self.manager.gitlab.http_get(
             path, streamed=streamed, raw=True, **kwargs
         )
