@@ -6,7 +6,7 @@ from sys import version_info
 import pytest
 from setuptools import sandbox
 
-from gitlab import __title__, __version__
+from gitlab._version import __title__, __version__
 
 DIST_DIR = Path("dist")
 DOCS_DIR = "docs"
@@ -31,4 +31,4 @@ def test_sdist_includes_tests(build):
 
 def test_wheel_excludes_docs_and_tests(build):
     wheel = zipfile.ZipFile(DIST_DIR / WHEEL_FILE)
-    assert not any([file.startswith((DOCS_DIR, TEST_DIR)) for file in wheel.namelist()])
+    assert not any(file.startswith((DOCS_DIR, TEST_DIR)) for file in wheel.namelist())
